@@ -1,14 +1,16 @@
 context("sf: dplyr syntax")
 
-suppressMessages(library(dplyr))
+suppressMessages(require(dplyr, quietly = TRUE))
 nc <- st_read(system.file("shape/nc.shp", package="sf"), quiet = TRUE)
 
 test_that("select works", {
+  skip_if_not_installed("dplyr")
   expect_true(nc %>% select_("AREA", attr(., "sf_column"))  %>% inherits("sf"))
   expect_true(nc %>% select(AREA) %>% inherits("sf"))
 })
 
 test_that("filter to sfc works", {
+  skip_if_not_installed("dplyr")
   tbl = tibble(a = c("A", "B", "C"),
               geometry = st_sfc(st_point(c(1, 1)),
                                 st_point(),
@@ -20,14 +22,16 @@ test_that("filter to sfc works", {
                    d[1:2, ])
 })
 
-suppressMessages(library(tidyr))
+suppressMessages(require(tidyr, quietly = TRUE))
 test_that("separate and unite work", {
+  skip_if_not_installed("dplyr")
   expect_true(nc %>% separate(CNTY_ID, c("a", "b"), sep = 2) %>% inherits("sf"))
   expect_true(nc %>% separate(CNTY_ID, c("a", "b"), sep = 2) %>%
 	unite(CNTY_ID_NEW, c("a", "b"), sep = "") %>% inherits("sf"))
 })
 
 test_that("separate_rows work", {
+  skip_if_not_installed("dplyr")
   d <- st_as_sf(data.frame(
     x = seq_len(3),
     y = c("a", "d,e,f", "g,h"),
@@ -50,6 +54,7 @@ test_that("separate_rows work", {
 })
 
 test_that("group/ungroup works", {
+ skip_if_not_installed("dplyr")
  tbl = tibble(a = c(1,1,2,2), g = st_sfc(st_point(0:1), st_point(1:2), st_point(2:3), st_point(3:4)))
  d = st_sf(tbl)
  e <- d %>% group_by(a) %>% ungroup
@@ -57,6 +62,7 @@ test_that("group/ungroup works", {
 })
 
 test_that("sample_n etc work", {
+	skip_if_not_installed("dplyr")
 	tbl = tibble(a = c(1,1,2,2), g = st_sfc(st_point(0:1), st_point(1:2), st_point(2:3), st_point(3:4)))
 	d = st_sf(tbl)
 
@@ -72,6 +78,7 @@ test_that("sample_n etc work", {
 })
 
 test_that("nest() works", {
+	skip_if_not_installed("dplyr")
 	tbl = tibble(a = c(1,1,2,2), g = st_sfc(st_point(0:1), st_point(1:2), st_point(2:3), st_point(3:4)))
 	d = st_sf(tbl)
 	out = d %>% group_by(a) %>% nest()
@@ -99,6 +106,7 @@ test_that("st_intersection of tbl returns tbl", {
 })
 
 test_that("unnest works", {
+  skip_if_not_installed("dplyr")
   skip_if_not_installed("tidyr")
   skip_if_not(utils::packageVersion("tidyr") > "0.7.2")
   nc = read_sf(system.file("shape/nc.shp", package = "sf")) %>%
@@ -207,6 +215,7 @@ test_that("bind_cols() returns type of first input", {
 })
 
 test_that("can rename geometry column with `select()`", {
+	skip_if_not_installed("dplyr")
 	sf = st_sf(
 		x = 1,
 		geo = st_sfc(st_point(1:2)),
@@ -219,3 +228,51 @@ test_that("can rename geometry column with `select()`", {
 	out = dplyr::select(sf, y)
 	expect_identical(out, st_sf(geo = sf$geo, y = sf$y))
 })
+
+test_that("can rename geometry column with `rename()` (#1431)", {
+	skip_if_not_installed("dplyr")
+	geo_pt = st_sfc(st_point())
+	geo_ln = st_sfc(st_linestring())
+	sf = st_sf(x = 1, geo2 = geo_pt, geo1 = geo_ln, sf_column_name = "geo1")
+
+	expect_identical(
+		dplyr::rename(sf, y = x),
+		st_sf(y = 1, geo2 = geo_pt, geo1 = geo_ln, sf_column_name = "geo1")
+	)
+
+	expect_identical(
+		dplyr::rename(sf, foo = geo1),
+		st_sf(x = 1, geo2 = geo_pt, foo = geo_ln, sf_column_name = "foo")
+	)
+	expect_identical(
+		dplyr::rename(sf, foo = geo1, y = x),
+		st_sf(y = 1, geo2 = geo_pt, foo = geo_ln, sf_column_name = "foo")
+	)
+	expect_identical(
+		dplyr::rename(sf, foo = geo1, y = x, bar = geo2),
+		st_sf(y = 1, bar = geo_pt, foo = geo_ln, sf_column_name = "foo")
+	)
+})
+
+test_that("`select()` and `transmute()` observe back-stickiness of geometry column (#1425)", {
+	skip_if_not_installed("dplyr")
+	sf = read_sf(system.file("shape/nc.shp", package = "sf"))
+	exp = sf[, c("NAME", "FIPS")]
+	expect_identical(dplyr::select(sf, NAME, FIPS), exp)
+	expect_identical(dplyr::transmute(sf, NAME, FIPS), exp)
+})
+
+test_that("rowwise_df class is retained on row slice", {
+	skip_if_not_installed("dplyr")
+	expect_true(nc %>% rowwise() %>% slice(1) %>% inherits("rowwise_df"))
+})
+
+test_that("grouped_df class is retained on row slice", {
+	skip_if_not_installed("dplyr")
+	expect_true(nc %>% group_by(PERIMETER > 2) %>% slice(1) %>% inherits("grouped_df"))
+})
+
+test_that("rowwise_df class is retained on filtered rows", {
+	skip_if_not_installed("dplyr")
+	expect_true(nc %>% rowwise() %>% filter(AREA > .1) %>% inherits("rowwise_df"))
+})
